==> zio-aws-clouddirectory_2.12-6.20.120.1-sources.jar: zio/aws/clouddirectory/model/BatchListPolicyAttachmentsResponse.scala <==
package zio.aws.clouddirectory.model
import zio.aws.clouddirectory.model.primitives.{NextToken, ObjectIdentifier}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class BatchListPolicyAttachmentsResponse(
    objectIdentifiers: Optional[Iterable[ObjectIdentifier]] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.clouddirectory.model.BatchListPolicyAttachmentsResponse = {
    import BatchListPolicyAttachmentsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.clouddirectory.model.BatchListPolicyAttachmentsResponse
      .builder()
      .optionallyWith(
        objectIdentifiers.map(value =>
          value.map { item =>
            ObjectIdentifier.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.objectIdentifiers)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.clouddirectory.model.BatchListPolicyAttachmentsResponse.ReadOnly =
    zio.aws.clouddirectory.model.BatchListPolicyAttachmentsResponse
      .wrap(buildAwsValue())
}
object BatchListPolicyAttachmentsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.clouddirectory.model.BatchListPolicyAttachmentsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.clouddirectory.model.BatchListPolicyAttachmentsResponse =
      zio.aws.clouddirectory.model.BatchListPolicyAttachmentsResponse(
        objectIdentifiers.map(value => value),
        nextToken.map(value => value)
      )
    def objectIdentifiers: Optional[List[ObjectIdentifier]]
    def nextToken: Optional[NextToken]
    def getObjectIdentifiers: ZIO[Any, AwsError, List[ObjectIdentifier]] =
      AwsError.unwrapOptionField("objectIdentifiers", objectIdentifiers)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.clouddirectory.model.BatchListPolicyAttachmentsResponse
  ) extends zio.aws.clouddirectory.model.BatchListPolicyAttachmentsResponse.ReadOnly {
    override val objectIdentifiers: Optional[List[ObjectIdentifier]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.objectIdentifiers())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.clouddirectory.model.primitives.ObjectIdentifier(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.clouddirectory.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.clouddirectory.model.BatchListPolicyAttachmentsResponse
  ): zio.aws.clouddirectory.model.BatchListPolicyAttachmentsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-clouddirectory_2.13-5.17.102.9-sources.jar: zio/aws/clouddirectory/model/BatchListPolicyAttachmentsResponse.scala <==
package zio.aws.clouddirectory.model
import zio.aws.clouddirectory.model.primitives.{NextToken, ObjectIdentifier}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class BatchListPolicyAttachmentsResponse(
    objectIdentifiers: Option[Iterable[ObjectIdentifier]] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.clouddirectory.model.BatchListPolicyAttachmentsResponse = {
    import BatchListPolicyAttachmentsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.clouddirectory.model.BatchListPolicyAttachmentsResponse
      .builder()
      .optionallyWith(
        objectIdentifiers.map(value =>
          value.map { item =>
            ObjectIdentifier.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.objectIdentifiers)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.clouddirectory.model.BatchListPolicyAttachmentsResponse.ReadOnly =
    zio.aws.clouddirectory.model.BatchListPolicyAttachmentsResponse
      .wrap(buildAwsValue())
}
object BatchListPolicyAttachmentsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.clouddirectory.model.BatchListPolicyAttachmentsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.clouddirectory.model.BatchListPolicyAttachmentsResponse =
      zio.aws.clouddirectory.model.BatchListPolicyAttachmentsResponse(
        objectIdentifiers.map(value => value),
        nextToken.map(value => value)
      )
    def objectIdentifiers: Option[List[ObjectIdentifier]]
    def nextToken: Option[NextToken]
    def getObjectIdentifiers: ZIO[Any, AwsError, List[ObjectIdentifier]] =
      AwsError.unwrapOptionField("objectIdentifiers", objectIdentifiers)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.clouddirectory.model.BatchListPolicyAttachmentsResponse
  ) extends zio.aws.clouddirectory.model.BatchListPolicyAttachmentsResponse.ReadOnly {
    override val objectIdentifiers: Option[List[ObjectIdentifier]] = scala
      .Option(impl.objectIdentifiers())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.clouddirectory.model.primitives.ObjectIdentifier(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.clouddirectory.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.clouddirectory.model.BatchListPolicyAttachmentsResponse
  ): zio.aws.clouddirectory.model.BatchListPolicyAttachmentsResponse.ReadOnly =
    new Wrapper(impl)
}
